@@ -1,13 +1,15 @@
 from .base.SerializableObject import SerializableObject
+from .base.MetaDataObject import MetaDataObject
 from .CheckRun import CheckRun
 
 
-class CheckSuite(SerializableObject):
+class CheckSuite(SerializableObject, MetaDataObject):
     ##################################################################################################
     # Constructor
     ##################################################################################################
-    def __init__(self, name, checks=None):
+    def __init__(self, name, checks=None, meta_data=None):
         SerializableObject.__init__(self)
+        MetaDataObject.__init__(self, meta_data)
         self.name = name
         if checks is None:
             checks = []
@@ -27,6 +29,10 @@ class CheckSuite(SerializableObject):
     ##################################################################################################
     # Properties
     ##################################################################################################
+    @property
+    def version(self):
+        return self._version
+
     @property
     def name(self):
         return self._name
